@@ -18,10 +18,11 @@ template_plugin = template.Cheetah()
 enable_debug = False
 enable_sessions = False
 
-port = 8080
-host = '0.0.0.0'
-#user = nobody
-#group = nobody
+server_port = 8080
+server_host = '127.0.0.1'
+server_reload = True
+#server_user = 'nobody'
+#server_group = 'nobody'
 
 
 #add other variables here. They will be 
