@@ -9,6 +9,18 @@ class SimplewebApp(object):
 	def __call__(self, environ, start_response):
 		return self.wsgiapp(environ, start_response)
 
+class SimplewebReloadingApp(object):
+	def __call__(self, environ, start_response):
+		import simpleweb._urls
+		import simpleweb.settings
+
+		urls = simpleweb._urls
+		config = simpleweb.settings.Config("config")
+
+		wsgiapp = _create_app(urls, config)
+		return wsgiapp(environ, start_response)
+		
+
 def _create_app(url, config):
 	try:
 		sys.path.insert(0, '.')
@@ -19,7 +31,7 @@ def _create_app(url, config):
 	app = url.geturls()
 
 	#TODO: make middleware stack configurable
-	app = StaticMiddleware(app, config.dirname)
+	app = StaticMiddleware(app, config.working_directory)
 	#TODO: make auth middleware plug-able
 	if hasattr(config, 'auth_plugin'):
 		app = AuthMiddleware(app, authuser_class=config.auth_plugin.authuser_class)
@@ -27,6 +39,4 @@ def _create_app(url, config):
 	if config.enable_sessions:
 		app = SessionMiddleware(DiskSessionStore(), app)
 
-	app.modules = sys.modules.keys()
 	return app
-
