@@ -1,6 +1,5 @@
 import selector,yaro
-import simpleweb
-import utils
+import simpleweb.utils
 
 class wrapper(yaro.Yaro):
 	def __call__(self, environ, start_response):
@@ -13,8 +12,8 @@ class wrapper(yaro.Yaro):
 			environ['yaro.request'] = req 
 
 		#make session object available easily via request object
-		if utils.ENV_KEY_FLUP_SESSION in environ:
-			req.session = environ[utils.ENV_KEY_FLUP_SESSION].session
+		if simpleweb.utils.ENV_KEY_FLUP_SESSION in environ:
+			req.session = environ[simpleweb.utils.ENV_KEY_FLUP_SESSION].session
 
 		body = self.app(req, **environ['selector.vars'])
 		if body is None:
@@ -31,13 +30,17 @@ class wrapper(yaro.Yaro):
 class Urls(object):
 	def __init__(self, **kw):
 		self.urls = selector.Selector(wrap=wrapper)
-		self.urlmap = {}
+		self.urlmap = []
 
 	def add(self, url, controller):
-		self.urlmap[url] = controller
-		method_dict = simpleweb.utils.get_methods_dict(controller, ['GET', 'POST', 'PUT', 'DELETE'])
-		self.urls.add(url, method_dict)
+		self.urlmap.append((url, controller))
+
+	def _setup(self):
+		for url, controller in self.urlmap:
+			method_dict = simpleweb.utils.get_methods_dict(controller, ['GET', 'POST', 'PUT', 'DELETE'])
+			self.urls.add(url, method_dict)
 
 	def geturls(self):
+		self._setup()
 		return self.urls
 
