@@ -5,7 +5,8 @@ def get_models():
 	try:
 		return __import__('models')
 	except ImportError, e:
-		sys.stderr.write("%s: Is this a valid simpleweb project directory?\n")
+		sys.stderr.write("Could not successfully import 'models.py'. Details Below:\n\t%s\n" % (e))
+		sys.exit(1)
 
 def get_tables_from_model(model, tabletype):
 	for(name, table) in vars(model).iteritems():
